;; Generated package description from lisp-ts-mode.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "lisp-ts-mode" "0.3.0" "lisp-mode with tree-sitter support" '((emacs "30.2") (cond-star "0") (compat "31")) :commit "15d86f40335c8be20250f7f86d0476b1c3a4ac90" :authors '(("zach shaftel" . "zach@shaf.tel")) :maintainer '("zach shaftel" . "zach@shaf.tel") :keywords '("lisp" "languages" "tree-sitter") :url "https://codeberg.org/zshaftel/lisp-ts-mode")
